==> zwap_design_system-0.1.536.tar.gz: lib/atoms/marquee_widget.dart <==
import 'package:flutter/material.dart';

class MarqueeWidget extends StatefulWidget {
  final Widget child;
  final Axis direction;
  final Duration animationDuration, backDuration, pauseDuration;

  MarqueeWidget({
    required this.child,
    this.direction: Axis.horizontal,
    this.animationDuration: const Duration(milliseconds: 3000),
    this.backDuration: const Duration(milliseconds: 800),
    this.pauseDuration: const Duration(milliseconds: 800),
  });

  @override
  _MarqueeWidgetState createState() => _MarqueeWidgetState();
}

class _MarqueeWidgetState extends State<MarqueeWidget> {
  ScrollController? scrollController;

  @override
  void initState() {
    scrollController = ScrollController(initialScrollOffset: 50.0);
    WidgetsBinding.instance!.addPostFrameCallback(scroll);
    super.initState();
  }

  @override
  void dispose() {
    scrollController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return NotificationListener<ScrollEndNotification>(
      onNotification: (notification) {
        // Per evitare che il NotificationListener in FixedSizeListView riceva le notifiche di questa scrollview
        return true;
      },
      child: SingleChildScrollView(
        child: widget.child,
        scrollDirection: widget.direction,
        controller: scrollController,
      ),
    );
  }

  void scroll(_) async {
    while (scrollController!.hasClients) {
      await Future.delayed(widget.pauseDuration);
      if (scrollController!.hasClients) await scrollController!.animateTo(scrollController!.position.maxScrollExtent, duration: widget.animationDuration, curve: Curves.ease);
      await Future.delayed(widget.pauseDuration);
      if (scrollController!.hasClients) await scrollController!.animateTo(0.0, duration: widget.backDuration, curve: Curves.easeOut);
    }
  }
}

==> zwap_design_system-0.1.574.tar.gz: lib/atoms/marquee_widget.dart <==
import 'package:flutter/material.dart';

class MarqueeWidget extends StatefulWidget {
  final Widget child;
  final Axis direction;
  final Duration animationDuration, backDuration, pauseDuration;

  MarqueeWidget({
    required this.child,
    this.direction: Axis.horizontal,
    this.animationDuration: const Duration(milliseconds: 3000),
    this.backDuration: const Duration(milliseconds: 800),
    this.pauseDuration: const Duration(milliseconds: 800),
  });

  @override
  _MarqueeWidgetState createState() => _MarqueeWidgetState();
}

class _MarqueeWidgetState extends State<MarqueeWidget> {
  ScrollController? scrollController;

  @override
  void initState() {
    scrollController = ScrollController(initialScrollOffset: 50.0);
    WidgetsBinding.instance?.addPostFrameCallback(scroll);
    super.initState();
  }

  @override
  void dispose() {
    scrollController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return NotificationListener<ScrollEndNotification>(
      onNotification: (notification) {
        // Per evitare che il NotificationListener in FixedSizeListView riceva le notifiche di questa scrollview
        return true;
      },
      child: SingleChildScrollView(
        child: widget.child,
        scrollDirection: widget.direction,
        controller: scrollController,
      ),
    );
  }

  void scroll(_) async {
    while (scrollController!.hasClients) {
      await Future.delayed(widget.pauseDuration);
      if (scrollController!.hasClients) await scrollController!.animateTo(scrollController!.position.maxScrollExtent, duration: widget.animationDuration, curve: Curves.ease);
      await Future.delayed(widget.pauseDuration);
      if (scrollController!.hasClients) await scrollController!.animateTo(0.0, duration: widget.backDuration, curve: Curves.easeOut);
    }
  }
}
